Crate use_computing_constants

Crate use_computing_constants 

Reusable computing constants expressed as plain integer values.

Constants

BITS_PER_BYTE
Exact computing constant for the number of bits in one byte.
BYTE_VALUES
Exact computing constant for the number of distinct values in one byte.
GIBIBYTE
Binary storage constant for one gibibyte, in bytes.
GIGABYTE
Decimal storage constant for one gigabyte, in bytes.
KIBIBYTE
Binary storage constant for one kibibyte, in bytes.
KILOBYTE
Decimal storage constant for one kilobyte, in bytes.
MEBIBYTE
Binary storage constant for one mebibyte, in bytes.
MEGABYTE
Decimal storage constant for one megabyte, in bytes.
NIBBLE_BITS
Exact computing constant for the number of bits in one nibble.
TEBIBYTE
Binary storage constant for one tebibyte, in bytes.
TERABYTE
Decimal storage constant for one terabyte, in bytes.